@@ -26,14 +26,17 @@ NULL
 #' @export
 
 layout_rotate <- function(xy,angle){
+  if(!"matrix"%in%class(xy)){
+    stop("xy must be a matrix")
+  }
+  if(!is.numeric(angle)){
+    stop("angle must be numeric")
+  }
   radians <- angle * pi / 180
   s <- sin(radians)
   c <- cos(radians)
 
-  xnew <- xy[ ,1] * c - xy[ ,2] * s
-  ynew <- xy[ ,1] * s + xy[ ,2] * c
-
-  cbind(xnew,ynew)
+  cbind(xy[ ,1] * c - xy[ ,2] * s,xy[ ,1] * s + xy[ ,2] * c)
 
 }
 
@@ -41,13 +44,10 @@ layout_rotate <- function(xy,angle){
 #' @export
 
 layout_mirror <- function(xy,axis = "vertical"){
-  if(grepl(axis,"vertical")){
-    axis <- "vertical"
-  } else if(grepl(axis,"horizontal")){
-    axis <- "horizontal"
-  } else{
-    stop("axis must be vertical, horizontal or an abbreviation of the two.")
+  if(!"matrix"%in%class(xy)){
+    stop("xy must be a matrix")
   }
+  axis <- match.arg(axis,c("horizontal","vertical"))
   if(axis=="horizontal"){
     middle <- mean(xy[,2])
     ynew <- middle - (xy[,2] - middle)
@@ -57,5 +57,7 @@ layout_mirror <- function(xy,axis = "vertical"){
     xnew <- middle - (xy[,1] - middle)
     ynew <- xy[,2]
   }
-  cbind(xnew,ynew)
+  xynew <- cbind(xnew,ynew)
+  colnames(xynew) <- NULL
+  xynew
 }
